@@ -13,7 +13,7 @@ import wandb
 
 from scipy.sparse import coo_matrix
 
-from .utils import profile, prepare_artifact
+from ..utils import profile, prepare_artifact
 
 if TYPE_CHECKING:
     from my_tools.utils import SparseTensor
